@@ -1,5 +1,8 @@
 from typing import Dict, NamedTuple, Optional, TypedDict
 
+import validators
+
+from ..errors import CliError
 from .config import Config
 
 
@@ -11,6 +14,8 @@ class Profile(NamedTuple):
 
 
 class OrgParams(TypedDict, total=False):
+    ssh_user: str
+    domain: str
     aws_saml_url: str
     aws_okta_params: Dict[str, str]
     saml2aws_params: Dict[str, str]
@@ -19,6 +24,8 @@ class OrgParams(TypedDict, total=False):
 
 PARAMS: Dict[str, OrgParams] = {
     "launch-darkly": {
+        "ssh_user": "ubuntu",
+        "domain": "launchdarkly.com",
         "aws_saml_url": "https://launchdarkly.okta.com/home/amazon_aws/0oaj4aow7gPk26Fy6356/272",
         "aws_okta_params": {
             "mfa_provider": "OKTA",
@@ -56,6 +63,8 @@ PARAMS: Dict[str, OrgParams] = {
         },
     },
     "sym": {
+        "ssh_user": "ubuntu",
+        "domain": "symops.io",
         "aws_okta_params": {},
         "saml2aws_params": {"mfa": "Auto"},
         "profiles": {
@@ -77,8 +86,7 @@ PARAMS: Dict[str, OrgParams] = {
 
 
 def get_org_params() -> OrgParams:
-    config = Config()
-    return PARAMS[config.get_org()]
+    return PARAMS[Config.get_org()]
 
 
 def get_aws_saml_url(resource: str) -> str:
@@ -99,5 +107,29 @@ def get_profiles() -> Dict[str, Profile]:
     return get_org_params()["profiles"]
 
 
+def get_domain() -> str:
+    return get_org_params()["domain"]
+
+
+def get_ssh_user() -> str:
+    return get_org_params()["ssh_user"]
+
+
 def get_profile(resource: str) -> Profile:
     return get_profiles()[resource]
+
+
+def set_login_fields(org: str, email: str):
+    if org not in PARAMS:
+        raise CliError(f"Invalid org: {org}")
+
+    config = Config.instance()
+    config["org"] = org
+
+    if not validators.email(email):
+        raise CliError(f"Invalid email: {email}")
+
+    if (domain := email.split("@")[-1]) != get_domain():
+        raise CliError(f"Invalid domain: {domain}")
+
+    config["email"] = email
