@@ -15,10 +15,10 @@ class CaptureCommand:
 
     # This function is designed for capturing the run_subprocess decorator only.
     # It is not intended to capture subprocess.run calls generally. For example,
-    # it returns None rather than CompletedProcess, and `args` has a much more
-    # constrained type than subprocess.run normally allows.
+    # `args` has a much more constrained type than subprocess.run normally allows.
     def _run_stub(self, args: Sequence[str], **_kwargs: Any) -> None:
         self.commands.append(list(args))
+        return subprocess.CompletedProcess(args=args, returncode=0)
 
     @contextmanager
     def __call__(self) -> Iterator[None]:
